#!/bin/bash
export LANG=en_US.UTF-8
_stage=$1
_stage_lock="/root/initial/tasks/${_stage}.done"
_puppet_server=hensonm.hostgator.com
_puppet_ca=hensonca.hostgator.com

if [ "${LOCATION}" == 'provo_ace' ]; then
    _puppet_server=ace-proxy1-hensonm.hostgator.com
    _puppet_ca=ace-proxy1-hensonm.hostgator.com
fi

stage1() {
    check_stage
    tuned-adm profile virtual-host
    virsh net-destroy default
    virsh net-undefine default
    timedatectl set-timezone "${TIME_ZONE}"
    timedatectl set-local-rtc 0
    timedatectl set-ntp true
    FACTER_foreman_organization=${BRAND} FACTER_foreman_location=${LOCATION} puppet agent -t --server ${_puppet_server} --ca_server ${_puppet_ca} --ssldir '$vardir/ssl' --tags foreman_registration
    while [ $? -eq 1 ]; do
        sleep 5
	FACTER_foreman_organization=${BRAND} FACTER_foreman_location=${LOCATION} puppet agent -t --server ${_puppet_server} --ca_server ${_puppet_ca} --ssldir '$vardir/ssl' --tags foreman_registration
    done
    touch "${_stage_lock}"
}

stage2() {
    check_stage
    puppet agent -t --server ${_puppet_server} --ca_server ${_puppet_ca} --ssldir '$vardir/ssl' --tags=yum_repos,puppet_agent
    while [ $? -eq 1 ]; do
        sleep 5
        puppet agent -t --server ${_puppet_server} --ca_server ${_puppet_ca} --ssldir '$vardir/ssl' --tags=yum_repos,puppet_agent
    done
    yum clean all -y --enablerepo=*
    yum makecache
    yum update -y
    yum install -y kernelcare
    touch "${_stage_lock}"
}

stage3() {
    check_stage
    puppet agent -t
    puppet agent -t
    puppet agent -t
    service ntpd status &> /dev/null && service ntpd stop
    ntpd -gq
    find /etc/pki/rpm-gpg -type f -exec rpm --import {} \;
    touch "${_stage_lock}"
}

stage4() {
    check_stage
    yum -y remove initial-scripts-SERVER-NODE
    echo "Rebooting in 2 Minutes"
    echo "shutdown -rf now" | at now + 2 min
    touch "${_stage_lock}"
}

check_stage() {
    if [ -f "${_stage_lock}" ]; then
        exit 0
    fi
    echo "Running ${_stage}"
}

${_stage}
